@@ -20,13 +20,12 @@
 import logging
 from unittest import mock
 
-import pyresample.ewa
-
-import pytest
 import numpy as np
-
+import pytest
 from pyproj import CRS
 
+import pyresample.ewa
+
 da = pytest.importorskip("dask.array")
 xr = pytest.importorskip("xarray")
 dask_ewa = pytest.importorskip("pyresample.ewa.dask_ewa")
@@ -59,7 +58,7 @@ def _get_test_array(input_shape, input_dtype, chunk_size):
 
 def _get_test_swath_def(input_shape, chunk_size, geo_dims):
     from pyresample.geometry import SwathDefinition
-    from pyresample.test.utils import create_test_longitude, create_test_latitude
+    from pyresample.test.utils import create_test_latitude, create_test_longitude
     lon_arr = create_test_longitude(-95.0, -75.0, input_shape, dtype=np.float64)
     lat_arr = create_test_latitude(15.0, 30.0, input_shape, dtype=np.float64)
     lons = da.from_array(lon_arr, chunks=chunk_size)
